@@ -1,7 +1,7 @@
 /* amitk_tree_view.h
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2002-2007 Andy Loening
+ * Copyright (C) 2002-2009 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -34,10 +34,10 @@
 G_BEGIN_DECLS
 
 #define AMITK_TYPE_TREE_VIEW            (amitk_tree_view_get_type ())
-#define AMITK_TREE_VIEW(obj)            (GTK_CHECK_CAST ((obj), AMITK_TYPE_TREE_VIEW, AmitkTreeView))
-#define AMITK_TREE_VIEW_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), AMITK_TYPE_THESHOLD, AmitkTreeViewClass))
-#define AMITK_IS_TREE_VIEW(obj)         (GTK_CHECK_TYPE ((obj), AMITK_TYPE_TREE_VIEW))
-#define AMITK_IS_TREE_VIEW_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), AMITK_TYPE_TREE_VIEW))
+#define AMITK_TREE_VIEW(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), AMITK_TYPE_TREE_VIEW, AmitkTreeView))
+#define AMITK_TREE_VIEW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), AMITK_TYPE_THESHOLD, AmitkTreeViewClass))
+#define AMITK_IS_TREE_VIEW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AMITK_TYPE_TREE_VIEW))
+#define AMITK_IS_TREE_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AMITK_TYPE_TREE_VIEW))
 
 typedef enum {
   AMITK_TREE_VIEW_MODE_MAIN,
